<?php
/*
Plugin Name: CookieTjek Cookie Linker
Version: 0.3
Description: Automatically links scripts from cookietjek.dk
Author: Michal Dobroczynski
Author URI: http://www.cookietjek.dk/
License: GPLv2
*/


class CookieTjekPlugin {
    
    function CookieTjekPlugin() {
        if(is_admin()) {
            add_action('admin_menu', array($this, 'admin_add_page'));
            add_action( 'admin_init', array($this, 'register_settings'));
        }
        else {
            add_action('wp_head', array($this, 'head'));
        }
        
    }

    /**
     * Output the vital code in <head></head>
     * Requires that wp_head() is placed in the template
     */
    function head() {
        $url = get_option("_ct_report_url");
        $path = get_option("_ct_cookie_path");
        $domain = get_option("_ct_domain");
        
        if(!(empty($url) || empty($path) || empty($domain))) {
            echo '<script type="text/javascript">var CookieTjekURL = "'.$url.'";
            window.CookieTjekOptions = { path: "'.$path.'", domain: "'.$domain.'"};</script>
            <script src="http://www.cookietjek.dk/widget/widget.min.js" type="text/javascript"></script>';    
        }        
    }
    
    /**
     * Options page
     */
    function options() {
        ?>
        <div class="wrap">
        <?php screen_icon(); ?>
        <h2>CookieTjek Options</h2>
        <form method="post" action="options.php">
        <?php
        settings_fields( 'cookietjek-group' );
        do_settings_fields('cookietjek-group' );
        ?>
        <p>
            Here you can configure your CookieTjek reporting options. 
        </p>
        <p>
            Cookie options control how CookieTjek cookies are set. If you are unsure how to set them - write "/" for path and your main domain in the domain control.
        </p>    
            
        <table class="form-table">
                <tr valign="top">
                <th scope="row">URL to CookieTjek report</th>
                <td><input type="text" size="50" name="_ct_report_url" value="<?php echo get_option('_ct_report_url'); ?>" /></td>
                </tr>
                 
                <tr valign="top">
                <th scope="row">Cookie option: path</th>
                <td><input type="text" name="_ct_cookie_path" value="<?php echo get_option('_ct_cookie_path'); ?>" /></td>
                </tr>
                
                <tr valign="top">
                <th scope="row">Cookie option: domain</th>
                <td><input type="text" name="_ct_domain" value="<?php echo get_option('_ct_domain'); ?>" /></td>
                </tr>
        </table>
        <?php 
        submit_button();
        ?>
        </form>
        <h3>Example</h3>
        <table class="form-table">
            <tr>
                <th>URL to CookieTjek report</th>
                <td>http://www.cookietjek.dk/cookies</td>
            </tr>
            <tr>
                <th>Cookie option: path</th>
                <td>/</td>        
            </tr>
            <tr>
                <th>Cookie option: domain</th>
                <td>.cookietjek.dk</td>
            </tr>
        </table>
        
        
        
        </div>
        <?php
    }

    function admin_add_page() {
        add_options_page("CookieTjek", "CookieTjek", "manage_options", "cookietjek-options", array($this, "options"));
    }

    function register_settings() {
        register_setting('cookietjek-group', '_ct_cookie_path');
        register_setting('cookietjek-group', '_ct_report_url');
        register_setting('cookietjek-group', '_ct_domain'); 
    }

}


$CookieTjek = new CookieTjekPlugin();




?>